@@ -318,15 +318,16 @@ def performSpineAnalysis2(
     # Calculate virtual sacrum point
     markersNew = {}
     markersNew['SACR'] = 0.5 * (markers['RPSI'] + markers['LPSI'])
-    markersNew['L4'] = 0.5 * (markers['RL4'] + markers['LL4'])
+    if 'L4' not in markers2:
+        markersNew['L4'] = 0.5 * (markers['RL4'] + markers['LL4'])
     markers2.update(markersNew)
     
     # Express points in PELVIS anatomical reference frame
     pointNames = [
+        'C7',
         'T12',
         'L2',
-        'L3',
-        'L3_TRUE',
+#        'L3',
         'LL4',
         'RL4',
         'L4',
@@ -345,12 +346,12 @@ def performSpineAnalysis2(
         idxs[idxName] = i
 
     colors = [
-        'b',
-        'b',
-        'b',
         'g',
         'b',
         'b',
+#        'b',
+        'b',
+        'b',
         'b',
         'r',
         'r',
@@ -381,9 +382,11 @@ def performSpineAnalysis2(
         if not os.path.exists(figuresDir):
             os.mkdir(figuresDir)
             
-    angleT12ToSACRToAntAxisSag = np.zeros((Nf,))
-    angleT12ToL4ToLatAxisFro = np.zeros((Nf,))
-        
+    angleT12ToL4ToUpAxisSag = np.zeros((Nf,))
+    angleT12ToL4ToUpAxisFro = np.zeros((Nf,))
+    angleC7ToT12ToUpAxisSag = np.zeros((Nf,))
+    angleC7ToT12ToUpAxisFro = np.zeros((Nf,))
+
     # Process data
     for i in iRange:
         
@@ -393,11 +396,21 @@ def performSpineAnalysis2(
         pointsDataSag = pointsData[i,1::-1,:].T     # Np x 2
         pointsDataFro = pointsData[i,1:,:].T        # Np x 2
         
-        tmp = pointsDataSag[idxs['idx_T12'],:] - pointsDataSag[idxs['idx_SACR'],:]
-        angleT12ToSACRToAntAxisSag[i] = np.rad2deg(np.arctan2(tmp[1], tmp[0]))
+        vec = pointsDataSag[idxs['idx_T12'],:] - pointsDataSag[idxs['idx_L4'],:]
+        vec = vec[::-1]
+        angleT12ToL4ToUpAxisSag[i] = -np.rad2deg(np.arctan2(vec[1], vec[0])) + 90
         
-        tmp = pointsDataSag[idxs['idx_T12'],:] - pointsDataSag[idxs['idx_L4'],:]
-        angleT12ToL4ToLatAxisFro[i] = np.rad2deg(np.arctan2(tmp[1], tmp[0]))
+        vec = pointsDataFro[idxs['idx_T12'],:] - pointsDataFro[idxs['idx_L4'],:]
+        vec = vec[::-1]
+        angleT12ToL4ToUpAxisFro[i] = -np.rad2deg(np.arctan2(vec[1], vec[0])) + 90
+        
+        vec = pointsDataSag[idxs['idx_C7'],:] - pointsDataSag[idxs['idx_T12'],:]
+        vec = vec[::-1]
+        angleC7ToT12ToUpAxisSag[i] = -np.rad2deg(np.arctan2(vec[1], vec[0])) + 90
+        
+        vec = pointsDataFro[idxs['idx_C7'],:] - pointsDataFro[idxs['idx_T12'],:]
+        vec = vec[::-1]
+        angleC7ToT12ToUpAxisFro[i] = -np.rad2deg(np.arctan2(vec[1], vec[0])) + 90
         
         if savePlots:
         
@@ -426,7 +439,9 @@ def performSpineAnalysis2(
         plt.close('all')
         
     res['newMarkers'] = markersNew
-    res['spineAngles']['T12ToSACRToAntAxisSag'] = angleT12ToSACRToAntAxisSag
-    res['spineAngles']['T12ToL4ToLatAxisFro'] = angleT12ToL4ToLatAxisFro
+    res['spineAngles']['T12ToL4ToUpAxisSag'] = angleT12ToL4ToUpAxisSag
+    res['spineAngles']['T12ToL4ToUpAxisFro'] = angleT12ToL4ToUpAxisFro
+    res['spineAngles']['C7ToT12ToUpAxisSag'] = angleC7ToT12ToUpAxisSag
+    res['spineAngles']['C7ToT12ToUpAxisFro'] = angleC7ToT12ToUpAxisFro
     
     return res
\ No newline at end of file
